@@ -26,9 +26,13 @@ class Hasher(Handler):
             # Fonts
             (?:font\/.*)|
             # JS
-            (?:(?:application|text)/(x-)?(?:java|ecma)script)|
+            # NOTE: "application/x-ecmascript" & "application/x-javascript"
+            # are deprecated (but supported). Also "text/javascript" is valid
+            # while "text/ecmascript" is not
+            (?:(?:application|text)\/(x-)?(?:java|ecma)script)|
             # JSON
-            (?:(?:application|text)\/(?:ld+)?json)|
+            # NOTE: "text/json" is deprecated (but supported)
+            (?:(?:application|text)\/(?:ld\+)?json)|
             # Images
             (?:image\/.*)|
             # XML
